from airflow.plugins_manager import AirflowPlugin
from .hooks.clickhouse_hook import ClickHouseHook
from .operators.clickhouse_operator import ClickHouseOperator


class ClickHouseOperatorPlugin(AirflowPlugin):
    name = 'clickhouse_operator'
    operators = [ClickHouseOperator]


class ClickHouseHookPlugin(AirflowPlugin):
    name = 'clickhouse_hook'
    hooks = [ClickHouseHook]



from typing import *

from airflow.models import BaseOperator

from airflow_clickhouse_plugin.hooks import clickhouse_hook


class ClickHouseOperator(BaseOperator):
    template_fields = ('_sql',)

    def __init__(
            self,
            sql: Union[str, Iterable[str]],
            clickhouse_conn_id: str = 'clickhouse_default',
            parameters: Dict[str, Any] = None,
            database=None,
            *args, **kwargs,
    ):
        super().__init__(*args, **kwargs)
        self._sql = sql
        self._conn_id = clickhouse_conn_id
        self._parameters = parameters
        self._database = database

    def execute(self, context: Dict[str, Any]) -> Any:
        hook = clickhouse_hook.ClickHouseHook(
            clickhouse_conn_id=self._conn_id,
            database=self._database,
        )
        return hook.run(self._sql, self._parameters)



#!/usr/bin/env python3

import os
from setuptools import setup, find_packages

# get key package details from airflow_clickhouse_plugin/__version__.py
about = {}
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'airflow_clickhouse_plugin', '__version__.py')) as f:
    exec(f.read(), about)

# load the README file and use it as the long_description for PyPI
with open(os.path.join(here, 'README.md'), 'r') as f:
    readme = f.read()

with open(os.path.join(here, 'requirements.txt')) as requirements_file:
    requirements = requirements_file.read().strip().split('\n')

setup(
    name=about['__title__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    version=about['__version__'],
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=find_packages(exclude=('tests',)),
    include_package_data=True,
    python_requires=">=3.6.*",
    install_requires=requirements,
    license=about['__license__'],
    zip_safe=False,
    entry_points={
        'airflow.plugins': [
            'airflow_clickhouse_hook '
                '= airflow_clickhouse_plugin:ClickHouseHookPlugin',
            'airflow_clickhouse_operator '
                '= airflow_clickhouse_plugin:ClickHouseOperatorPlugin',
        ]
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Plugins',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.6',
    ],
    keywords=['clickhouse', 'airflow'],
)
